/*
 * core.h - cve-check-tool
 *
 * Copyright (C) 2015 Intel Corporation
 *
 * cve-check-tool is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 */
#pragma once

#include "structs.h"

#include <list>
#include <map>
#include <memory>
#include <optional>
#include <set>
#include <string>

/**
 * A CVE Database, using the National Vulnerability Database as its source
 */
class CveDB
{
public:
    /**
     * Get CVE data for the given ID
     *
     * @param db A valid CveDB instance
     * @param id The CVE-XXXX-XXXX ID
     *
     * @return A newly allocated data structure, or NULL if the CVE is not found
     */
    std::optional<cve_entry_t> get_cve(const std::string &id) const;

    /**
     * Retrieve a list of CVEs for the given parameters
     *
     * @param db A valid CveDB instance
     * @param product The CPE product name
     * @param version A version string to match against
     *
     * @return A newly allocated list of strings if found, otherwise NULL
     */
    std::set<issue_t> get_issues(const std::string &vendor, const std::string &product, const std::string &software_platform, const std::string &version, std::set<discarded_issue_t> *discarded_issues_set) const;

    void load(const std::string &clickhouse_config_file, bool verbose);

    std::map<std::string, std::map<std::string, std::map<std::string, std::set<std::string> > > > product_issues_map;
    std::map<std::string, cve_entry_t> cve_map;
    std::set<std::string> explicit_vendors;
};

