/*
 * cve-check-tool.h
 *
 * Copyright (C) 2015 Intel Corporation
 *
 * cve-check-tool is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 */

#pragma once

#include <stdint.h>

#include <map>
#include <set>
#include <tuple>

#include "structs.h"

#include "core.h"

struct ExistingVulnerabilityStatus
{
        issue_status status = issue_status::actual;
        bool processed = false;

        ExistingVulnerabilityStatus() = default;
        ExistingVulnerabilityStatus(issue_status l_status, bool l_processed)
                : status(l_status)
                , processed(l_processed)
        {
        }
};

enum class QueryType {
        ALL,
        SRC_RPM,
        TASK_ID,
};

/**
 * Instance tracking
 */
typedef struct CveCheckTool {
        bool verbose = false;
        bool report_discarded_vulnerabilities = false;
        uint64_t commit_data_limit = 0;
        std::map<source_package_base, source_package_output_info> db;          /**<Mapping of packages */
        std::set<std::tuple<std::string, std::string, std::string> > product_db;  /**<Set of product names */
        CveDB cve_db;           /**<Mapping of CVEs */
        std::string clickhouse_config; /**<File containing configuration to used to connect to clickhouse database, if any */
        std::map<std::string, std::map<uint64_t, ExistingVulnerabilityStatus> > existing_vulnerabilities; /* cve -> murmur_hash -> status */
        std::map<std::string, std::set<std::tuple<std::string, std::string, std::string> > > pkgname_to_cpe_vendor_product_softwareplatform;

        QueryType query_type = QueryType::ALL;
        std::string src_pkg_name, src_pkg_version; /* selected source pkg name and EVR */
        std::string task_id; /* selected task id */
} CveCheckTool;
