/*
 * cve-check-tool.h
 *
 * Copyright (C) 2015-2016 Sergey Popovich <popovich_sergei@mail.ua>.
 *
 * cve-check-tool is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 */

#pragma once

#include <string>

class CveDbLock
{
public:
        /**
         * Enumerate to represent possible locking types to imply on the
         * database file
         */
        enum locktype {
                LT_READ = 0, /**<Shared lock type */
                LT_WRITE,    /**<Exclusive lock type */
                __LT_MAX
        };

#define LT_MAX (__LT_MAX - 1)

        enum { LOCK_WAIT_SECS = 5 * 60, }; /**<Wait for lock to aquire 5 minutes */

        explicit CveDbLock(const std::string &db_path);
        ~CveDbLock();

        CveDbLock(const CveDbLock &other) = delete;
        CveDbLock& operator=(const CveDbLock &other) = delete;

        bool cve_db_read_lock(int wait);
        bool cve_db_write_lock(int wait);
        void cve_db_unlock();

private:
    int db_lock_fd = -1;
    std::string db_lock_fname;

    bool cve_db_lock(locktype lt, int wait);
};
